{% load static  %}
<!-- highlight.js -->
<link href="{% static 'django_quill/highlight.darcula.min.css' %}" rel="stylesheet">
<script src="{% static 'django_quill/highlight.pack.js' %}"></script>

<!-- django-quill-editor -->
<link href="{% static 'django_quill/quill.snow.css' %}" rel="stylesheet">
<script src="{% static 'django_quill/quill.js' %}"></script>
<script src="{% static 'django_quill/django_quill.js' %}"></script>